@@ -88,6 +88,21 @@ sub FileType {
     return ($type);
 }
 
+sub StripPrintModeCmds {
+    local ($from, $to) = @_;
+    local (*IN, *OUT);
+
+    open(IN,  "<$from");
+    open(OUT, ">$to");
+    while (<IN>) {
+        next if (m|^\033%-12345X.*|);
+        next if (m|^\@PJL.*|);
+        print OUT $_;
+    }
+    close(OUT);
+    close(IN);
+}
+
 $uniq = 1;
 @tmpfiles = ();
 
